@@ -37,12 +37,12 @@ import logging
 import time
 from typing import Any, List, Union  # noqa F401
 
-import six
-
 import selenium.common.exceptions as selenium_exceptions
+import six
 from selenium import webdriver
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.common.keys import Keys
+
 from univention.testing.selenium.utils import expand_path
 
 logger = logging.getLogger(__name__)
@@ -59,7 +59,7 @@ class Interactions(object):
 		# type: (str, **Any) -> None
 		logger.info("Clicking the checkbox of the grid entry  %r", name)
 		self.click_element(
-			'//*[contains(concat(" ", normalize-space(@class), " "), " dgrid-cell ")][@role="gridcell"]//*[contains(text(), "%s")]/../..//input[@type="checkbox"]/..'
+			'//*[contains(concat(" ", normalize-space(@class), " "), " dgrid-cell ")][@role="gridcell"]/descendant-or-self::node()[contains(text(), "%s")]/../..//input[@type="checkbox"]/..'
 			% (name,),
 			**kwargs
 		)
@@ -141,22 +141,6 @@ class Interactions(object):
 			**kwargs
 		)
 
-	def click_tile_right_click(self, tilename, **kwargs):
-		# type: (str, **Any) -> None
-		logger.info("Right-Clicking the tile %r", tilename)
-		xpath = '//*[contains(concat(" ", normalize-space(@class), " "), " umcGalleryName ")][text() = "%s"]' % (tilename,)
-		elems = webdriver.support.ui.WebDriverWait(xpath, 60).until(
-			self.get_all_enabled_elements
-		)
-
-		if len(elems) != 1:
-			logger.warn(
-				"Found %d module tiles instead of 1. Trying to use the first "
-				"one." % (len(elems),)
-			)
-
-		ActionChains(self.driver).context_click(elems[0]).perform()
-
 	def click_tab(self, tabname, **kwargs):
 		# type: (str, **Any) -> None
 		logger.info("Clicking the tab %r", tabname)
@@ -186,7 +170,7 @@ class Interactions(object):
 		self.click_element(expand_path('//*[@containsClass="mobileMenu"]//*[@containsClass="menuSlideHeader"]'))
 		time.sleep(0.5)
 
-	def click_element(self, xpath, scroll_into_view=False, timeout=60):
+	def click_element(self, xpath, scroll_into_view=False, timeout=60, right_click=False):
 		# type: (str, bool, int) -> None
 		"""
 		Click on the element which is found by the given xpath.
@@ -195,7 +179,7 @@ class Interactions(object):
 		Waits for the element to be clickable before attempting to click.
 		"""
 		elems = webdriver.support.ui.WebDriverWait(xpath, timeout).until(
-			self.get_all_enabled_elements, 'click_element(%r, scroll_into_view=%r, timeout=%r)' % (xpath, scroll_into_view, timeout)
+			self.get_all_enabled_elements, 'click_element(%r, scroll_into_view=%r, timeout=%r, right_click=%r)' % (xpath, scroll_into_view, timeout, right_click)
 		)
 
 		if len(elems) != 1:
@@ -207,15 +191,21 @@ class Interactions(object):
 		if scroll_into_view:
 			self.driver.execute_script("arguments[0].scrollIntoView();", elems[0])
 		limit = timeout
-		while True:
-			try:
-				elems[0].click()
-				break
-			except selenium_exceptions.ElementClickInterceptedException:
-				limit -= 1
-				if limit == 0:
-					raise
-				time.sleep(1)
+		if right_click:
+			# context_click will always work since it triggers the browser context menu
+			# instead of throwing ElementClickInterceptedException.
+			# So we do not need to put it in the loop below
+			ActionChains(self.driver).context_click(elems[0]).perform()
+		else:
+			while True:
+				try:
+					elems[0].click()
+					break
+				except selenium_exceptions.ElementClickInterceptedException:
+					limit -= 1
+					if limit == 0:
+						raise
+					time.sleep(1)
 
 	def enter_input(self, inputname, inputvalue):
 		# type: (str, str) -> None
@@ -235,7 +225,21 @@ class Interactions(object):
 		else:
 			raise ValueError('value of input {!r} does not contain previously entered value ({!r} != {!r})'.format(inputname, inputvalue, elem.get_property('value')))
 
-	def enter_input_combobox(self, inputname, inputvalue):  # type: (str, str) -> None
+	def enter_input_combobox(self, inputname, inputvalue, with_click=True):  # type: (str, str) -> None
+		xpath = "//*[@role='combobox' and .//input[@name='{}']]//input[@role='textbox']".format(inputname)
+		elems = webdriver.support.ui.WebDriverWait(xpath, 60).until(
+			self.get_all_enabled_elements
+		)
+		if len(elems) != 1:
+			logger.warn("Found {!d} input elements instead of one. Try using the first one".format(len(elems)))
+		elems[0].clear()
+		elems[0].send_keys(inputvalue)
+		if with_click:
+			xpath = expand_path('//*[@containsClass="dijitMenuItem"]/descendant-or-self::node()[contains(text(), "%s")]' % (inputvalue))
+			self.wait_until_element_visible(xpath)
+			self.click_element(xpath)
+
+	def enter_input_date(self, inputname, inputvalue):  # type: (str, str) -> None
 		xpath = "//*[@role='combobox' and .//input[@name='{}']]//input[@role='textbox']".format(inputname)
 		elems = webdriver.support.ui.WebDriverWait(xpath, 60).until(
 			self.get_all_enabled_elements
@@ -244,9 +248,6 @@ class Interactions(object):
 			logger.warn("Found {:d} input elements instead of one. Try using the first one".format(len(elems)))
 		elems[0].clear()
 		elems[0].send_keys(inputvalue)
-		xpath = expand_path('//*[@containsClass="dijitMenuItem"]/descendant-or-self::node()[contains(text(), "%s")]' % (inputvalue))
-		self.wait_until_element_visible(xpath)
-		self.click_element(xpath)
 
 	def submit_input(self, inputname):
 		# type: (str) -> None
