@@ -35,11 +35,12 @@ from __future__ import absolute_import, print_function
 import time
 from typing import Any, Dict, Mapping, Optional  # noqa F401
 
-import univention.testing.strings as uts
-import univention.testing.ucr as ucr_test
 from selenium import webdriver
 from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.common.keys import Keys
+
+import univention.testing.strings as uts
+import univention.testing.ucr as ucr_test
 from univention.admin import localization
 
 translator = localization.translation('ucs-test-framework')
@@ -48,6 +49,8 @@ _ = translator.translate
 
 class UDMBase(object):
 
+	name = None
+
 	def __init__(self, selenium):
 		# type: (Any) -> None
 		self.selenium = selenium
@@ -74,6 +77,9 @@ class UDMBase(object):
 			pass
 		return False
 
+	def open_module(self):
+		self.selenium.open_module(self.name)
+
 	def open_details(self, objectname):
 		# type: (str) -> None
 		print('*** open detail page of object', objectname)
@@ -325,6 +331,31 @@ class Users(UDMBase):
 
 		return {'username': username, 'lastname': lastname}
 
+	def copy(self, user, username='', lastname='', password='univention', **kwargs):
+		username = username or uts.random_string()
+		self.search(user)
+		self.selenium.click_checkbox_of_grid_entry(user)
+		self.selenium.click_text(_('more'))
+		self.selenium.click_text(_('Copy'))
+		try:
+			self.selenium.wait_for_any_text_in_list(['Container', 'Template'], timeout=5)
+			self.selenium.click_button('Next')
+		except TimeoutException:
+			pass
+		finally:
+			self.selenium.wait_until_standby_animation_appears_and_disappears()
+
+		self.selenium.enter_input('username', username)
+		self.selenium.enter_input('lastname', lastname or uts.random_string())
+		self.selenium.enter_input('password_1', password)
+		self.selenium.enter_input('password_2', password)
+		for key, value in kwargs.items():
+			self.selenium.enter_input(key, value)
+		self.selenium.click_text(_('Create user'))
+		self.selenium.wait_until_standby_animation_appears_and_disappears()
+		# TODO: check for error
+		return username
+
 	def _get_search_value(self, user):
 		# type: (Mapping[str, str]) -> str
 		return user['username']
